@@ -43,7 +43,7 @@
 #define JRI_MD_H
 
 #include <assert.h>
-#include <nspr/prtypes.h> /* Needed for HAS_LONG_LONG ifdefs */
+#include <prtypes.h> /* Needed for HAS_LONG_LONG ifdefs */
 
 #ifdef __cplusplus
 extern "C" {
